.. _scipy-development:

Developer Documentation
-----------------------

Below you will find general information about contributing.
For an overview of where help or new features are desired or planned, see
the roadmap. And for a more detailed look at how the SciPy project works, see
the organization section.

.. toctree::
   :maxdepth: 1
   :caption: Contributing Information

   conduct/code_of_conduct
   hacking
   dev_quickstart
   contributor/development_workflow
   contributor/contributor_toc

.. toctree::
   :maxdepth: 1
   :caption: Roadmap

   roadmap
   roadmap-detailed
   toolchain

.. toctree::
   :maxdepth: 1
   :caption: SciPy Organization

   core-dev/index
   api-dev/api-dev-toc
   governance

.. This toctree defines previous/next for contributor guide documents
.. toctree::
   :hidden:

   contributor/development_workflow
   contributor/pep8
   contributor/rendering_documentation
   contributor/devpy_test
   contributor/benchmarking
   contributor/cython
   contributor/public_cython_api
   contributor/adding_new
   contributor/continuous_integration
   contributor/using_act
   triage

.. These files are not intended to be in any toctree. because they have not
   been maintained.They should only be reached via the contributor guide if
   they are specifically sought, not via next/previous links.
..   dev/gitwash/gitwash
..   dev/contributor/compiled_code
